pub struct BaseKey {
pub bytes: Vec<u8>,
}Expand description
A wrapper over Vec<u8> with functions for using it as a key prefix.
Fields
bytes: Vec<u8>The byte value of the key prefix.
Implementations
Sourceimpl BaseKey
impl BaseKey
Sourcepub fn base_tag_index(&self, tag: u8, index: &[u8]) -> Vec<u8> ⓘ
pub fn base_tag_index(&self, tag: u8, index: &[u8]) -> Vec<u8> ⓘ
Concatenates the base key, tag and index.
Sourcepub fn derive_key<I: Serialize>(&self, index: &I) -> Result<Vec<u8>, Error>
pub fn derive_key<I: Serialize>(&self, index: &I) -> Result<Vec<u8>, Error>
Obtains the Vec<u8> key from the key by serialization and using the base key.
Sourcepub fn derive_tag_key<I: Serialize>(
&self,
tag: u8,
index: &I,
) -> Result<Vec<u8>, Error>
pub fn derive_tag_key<I: Serialize>( &self, tag: u8, index: &I, ) -> Result<Vec<u8>, Error>
Obtains the Vec<u8> key from the key by serialization and using the base_key.
Sourcepub fn derive_short_key<I: Serialize + ?Sized>(
index: &I,
) -> Result<Vec<u8>, Error>
pub fn derive_short_key<I: Serialize + ?Sized>( index: &I, ) -> Result<Vec<u8>, Error>
Obtains the short Vec<u8> key from the key by serialization.
Sourcepub fn deserialize_value<Item: DeserializeOwned>(
bytes: &[u8],
) -> Result<Item, Error>
pub fn deserialize_value<Item: DeserializeOwned>( bytes: &[u8], ) -> Result<Item, Error>
Deserialize bytes into type Item.