pub struct ViewContext<E, S> { /* private fields */ }Expand description
Implementation of the Context trait on top of a DB client implementing
crate::store::KeyValueStore.
Implementations
Sourceimpl<E, S> ViewContext<E, S>where
S: ReadableKeyValueStore + WritableKeyValueStore,
impl<E, S> ViewContext<E, S>where
S: ReadableKeyValueStore + WritableKeyValueStore,
Sourcepub async fn create_root_context(store: S, extra: E) -> Result<Self, S::Error>
pub async fn create_root_context(store: S, extra: E) -> Result<Self, S::Error>
Creates a context suitable for a root view, using the given store. If the journal’s store is non-empty, it will be cleared first, before the context is returned.
Sourceimpl<E, S> ViewContext<E, S>
impl<E, S> ViewContext<E, S>
Sourcepub fn new_unchecked(store: S, base_key: Vec<u8>, extra: E) -> Self
pub fn new_unchecked(store: S, base_key: Vec<u8>, extra: E) -> Self
Creates a context for the given base key, store, and an extra argument. NOTE: this
constructor doesn’t check the journal of the store. In doubt, use
ViewContext::create_root_context instead.
Sourceimpl<E> ViewContext<E, MemoryStore>
impl<E> ViewContext<E, MemoryStore>
Sourcepub fn new_for_testing(extra: E) -> Self
pub fn new_for_testing(extra: E) -> Self
Creates a Context instance in memory for testing.