pub enum ViewError {
BcsError(Error),
IoError(Error),
ArithmeticError(ArithmeticError),
TryLockError(Vec<u8>),
TokioJoinError(JoinError),
StoreError {
backend: &'static str,
error: Box<dyn Error + Send + Sync>,
must_reload_view: bool,
},
KeyTooLong,
NotFound(String),
InconsistentEntries,
MissingEntries(String),
PostLoadValuesError,
}Expand description
Main error type for the crate.
Variants
BcsError(Error)
BCS serialization error.
IoError(Error)
Input output error.
ArithmeticError(ArithmeticError)
Arithmetic error
TryLockError(Vec<u8>)
Failed to lock a reentrant collection entry since it is currently being accessed
TokioJoinError(JoinError)
Tokio errors can happen while joining.
StoreError
Errors within the context can occur and are presented as ViewError.
Fields
KeyTooLong
The key must not be too long
NotFound(String)
The entry does not exist in memory
InconsistentEntries
The database is corrupt: Entries don’t have the expected hash.
MissingEntries(String)
The database is corrupt: Some entries are missing
PostLoadValuesError
The values are incoherent.
Implementations