LogView

Struct LogView 

pub struct LogView<C, T> { /* private fields */ }
A view that supports logging values of type T.

Implementations

Source

impl<C, T> LogView<C, T>
where C: Context,

pub fn push(&mut self, value: T)

Pushes a value to the end of the log.

let mut log = LogView::load(context).await.unwrap();
log.push(34);
pub fn count(&self) -> usize

Reads the size of the log.

let mut log = LogView::load(context).await.unwrap();
log.push(34);
log.push(42);
assert_eq!(log.count(), 2);
pub fn extra(&self) -> &C::Extra

Obtains the extra data.

Source

impl<C, T> LogView<C, T>

pub async fn get(&self, index: usize) -> Result<Option<T>, ViewError>

Reads the logged value with the given index (including staged ones).

let mut log = LogView::load(context).await.unwrap();
log.push(34);
assert_eq!(log.get(0).await.unwrap(), Some(34));
pub async fn multi_get( &self, indices: Vec<usize>, ) -> Result<Vec<Option<T>>, ViewError>

Reads several logged keys (including staged ones)

let mut log = LogView::load(context).await.unwrap();
log.push(34);
log.push(42);
assert_eq!(
    log.multi_get(vec![0, 1]).await.unwrap(),
    vec![Some(34), Some(42)]
);
pub async fn read<R>(&self, range: R) -> Result<Vec<T>, ViewError>
where R: RangeBounds<usize>,

Reads the logged values in the given range (including staged ones).

let mut log = LogView::load(context).await.unwrap();
log.push(34);
log.push(42);
log.push(56);
assert_eq!(log.read(0..2).await.unwrap(), vec![34, 42]);